==> bluez-qt-5.43.0.tar.xz: bluez-qt-5.43.0/src/macros.h <==
/*
 * BluezQt - Asynchronous Bluez wrapper library
 *
 * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BLUEZQT_MACROS_H
#define BLUEZQT_MACROS_H

// Change property value and emit propertyChanged signal
#define PROPERTY_CHANGED(var, type_cast, signal) \
    if (var != value.type_cast()) { \
        var = value.type_cast(); \
        Q_EMIT q.data()->signal(var); \
    }

#define PROPERTY_CHANGED2(var, value, signal) \
    const auto &val = value; \
    if (var != val) { \
        var = val; \
        Q_EMIT q.data()->signal(var); \
    }

// Clears property value and emit propertyChanged signal
#define PROPERTY_INVALIDATED(var, empty, signal) \
    if (var != empty) { \
        var = empty; \
        Q_EMIT q.data()->signal(var); \
    }

#endif // BLUEZQT_MACROS_H

==> bluez-qt-5.66.0.tar.xz: bluez-qt-5.66.0/src/macros.h <==
/*
 * BluezQt - Asynchronous Bluez wrapper library
 *
 * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BLUEZQT_MACROS_H
#define BLUEZQT_MACROS_H

// Change property value and emit propertyChanged signal
#define PROPERTY_CHANGED(var, type_cast, signal) \
    if (var != value.type_cast()) { \
        var = value.type_cast(); \
        Q_EMIT q.lock()->signal(var); \
    }

#define PROPERTY_CHANGED2(var, value, signal) \
    const auto &val = value; \
    if (var != val) { \
        var = val; \
        Q_EMIT q.lock()->signal(var); \
    }

// Clears property value and emit propertyChanged signal
#define PROPERTY_INVALIDATED(var, empty, signal) \
    if (var != empty) { \
        var = empty; \
        Q_EMIT q.lock()->signal(var); \
    }

#endif // BLUEZQT_MACROS_H
